@@ -65,7 +65,7 @@ jorg_search(edict_t *self)
 }
 
 /* stand */
-mframe_t jorg_frames_stand[] = {
+static mframe_t jorg_frames_stand[] = {
 	{ai_stand, 0, jorg_idle},
 	{ai_stand, 0, NULL},
 	{ai_stand, 0, NULL},
@@ -181,7 +181,7 @@ jorg_stand(edict_t *self)
 	self->monsterinfo.currentmove = &jorg_move_stand;
 }
 
-mframe_t jorg_frames_run[] = {
+static mframe_t jorg_frames_run[] = {
 	{ai_run, 17, jorg_step_left},
 	{ai_run, 0, NULL},
 	{ai_run, 0, NULL},
@@ -206,7 +206,7 @@ mmove_t jorg_move_run = {
 };
 
 /* walk */
-mframe_t jorg_frames_start_walk[] = {
+static mframe_t jorg_frames_start_walk[] = {
 	{ai_walk, 5, NULL},
 	{ai_walk, 6, NULL},
 	{ai_walk, 7, NULL},
@@ -221,7 +221,7 @@ mmove_t jorg_move_start_walk = {
    	NULL
 };
 
-mframe_t jorg_frames_walk[] = {
+static mframe_t jorg_frames_walk[] = {
 	{ai_walk, 17, NULL},
 	{ai_walk, 0, NULL},
 	{ai_walk, 0, NULL},
@@ -245,7 +245,7 @@ mmove_t jorg_move_walk = {
    	NULL
 };
 
-mframe_t jorg_frames_end_walk[] = {
+static mframe_t jorg_frames_end_walk[] = {
 	{ai_walk, 11, NULL},
 	{ai_walk, 0, NULL},
 	{ai_walk, 0, NULL},
@@ -290,7 +290,7 @@ jorg_run(edict_t *self)
 	}
 }
 
-mframe_t jorg_frames_pain3[] = {
+static mframe_t jorg_frames_pain3[] = {
 	{ai_move, -28, NULL},
 	{ai_move, -6, NULL},
 	{ai_move, -3, jorg_step_left},
@@ -325,7 +325,7 @@ mmove_t jorg_move_pain3 = {
    	jorg_run
 };
 
-mframe_t jorg_frames_pain2[] = {
+static mframe_t jorg_frames_pain2[] = {
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL}
@@ -338,7 +338,7 @@ mmove_t jorg_move_pain2 = {
    	jorg_run
 };
 
-mframe_t jorg_frames_pain1[] = {
+static mframe_t jorg_frames_pain1[] = {
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL}
@@ -351,7 +351,7 @@ mmove_t jorg_move_pain1 = {
    	jorg_run
 };
 
-mframe_t jorg_frames_death1[] = {
+static mframe_t jorg_frames_death1[] = {
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
@@ -411,7 +411,7 @@ mmove_t jorg_move_death = {
    	jorg_dead
 };
 
-mframe_t jorg_frames_attack2[] = {
+static mframe_t jorg_frames_attack2[] = {
 	{ai_charge, 0, NULL},
 	{ai_charge, 0, NULL},
 	{ai_charge, 0, NULL},
@@ -434,7 +434,7 @@ mmove_t jorg_move_attack2 = {
    	jorg_run
 };
 
-mframe_t jorg_frames_start_attack1[] = {
+static mframe_t jorg_frames_start_attack1[] = {
 	{ai_charge, 0, NULL},
 	{ai_charge, 0, NULL},
 	{ai_charge, 0, NULL},
@@ -452,7 +452,7 @@ mmove_t jorg_move_start_attack1 = {
    	jorg_attack1
 };
 
-mframe_t jorg_frames_attack1[] = {
+static mframe_t jorg_frames_attack1[] = {
 	{ai_charge, 0, jorg_firebullet},
 	{ai_charge, 0, jorg_firebullet},
 	{ai_charge, 0, jorg_firebullet},
@@ -468,7 +468,7 @@ mmove_t jorg_move_attack1 = {
    	jorg_reattack1
 };
 
-mframe_t jorg_frames_end_attack1[] = {
+static mframe_t jorg_frames_end_attack1[] = {
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
